@@ -1,17 +1,17 @@
-package Dist::Zilla::PluginBundle::Author::IOANR 1.172580;
+package Dist::Zilla::PluginBundle::Author::IOANR 1.173480;
 
 # ABSTRACT: Build dists the way IOANR likes
-use v5.12;
+
+use v5.24;
 use Moose;
 use List::Util 1.33 'any';
 use Dist::Zilla::Plugin::AssertOS;
-use Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes 0.107;
+use Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes 0.173421;
 use Dist::Zilla::Plugin::ContributorsFile;
 use Dist::Zilla::Plugin::CopyFilesFromBuild;
 use Dist::Zilla::Plugin::Git;
 use Dist::Zilla::Plugin::Git::Contributors;
 use Dist::Zilla::Plugin::GitHub;
-use Dist::Zilla::Plugin::Meta::Contributors;
 use Dist::Zilla::Plugin::MetaData::BuiltWith;
 use Dist::Zilla::Plugin::ModuleBuildTiny;
 use Dist::Zilla::Plugin::MojibakeTests;
@@ -21,14 +21,9 @@ use Dist::Zilla::Plugin::RunExtraTests;
 use Dist::Zilla::Plugin::Signature;
 use Dist::Zilla::Plugin::Test::CheckDeps;
 use Dist::Zilla::Plugin::Test::Compile;
-use Dist::Zilla::Plugin::Test::CPAN::Meta::JSON;
-use Dist::Zilla::Plugin::Test::DistManifest;
 use Dist::Zilla::Plugin::Test::EOL;
 use Dist::Zilla::Plugin::Test::Kwalitee;
-use Dist::Zilla::Plugin::Test::MinimumVersion;
 use Dist::Zilla::Plugin::Test::NoTabs;
-use Dist::Zilla::Plugin::Test::Pod::LinkCheck;
-use Dist::Zilla::Plugin::Test::Pod::No404s;
 use Dist::Zilla::Plugin::Test::Pod::No404s;
 use Dist::Zilla::Plugin::Test::Portability;
 use Dist::Zilla::Plugin::Test::ReportPrereqs;
@@ -39,8 +34,9 @@ use Dist::Zilla::Plugin::Test::Version;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
 # TODO optionally add OSPreqs
+# TODO Test::MinimumVersion - plugin generated test only checks META.yml, which we don't have
 
-has release_plugins => ( is => 'ro', lazy_build => 1);
+has release_plugins => (is => 'ro', lazy_build => 1);
 
 sub _build_release_plugins {
     my $self = shift;
@@ -51,7 +47,10 @@ sub _build_release_plugins {
 
     return [
         'ConfirmRelease',
-        ['Git::Commit' => {allow_dirty => [qw/README.md dist.ini Changes LICENSE/]}],
+        [
+            'Git::Commit' =>
+              {allow_dirty => [qw/README.md dist.ini Changes LICENSE/]}
+        ],
         [
             'Git::CommitBuild' => {
                 branch               => '',
@@ -62,7 +61,8 @@ sub _build_release_plugins {
         ],
         ['Git::Tag' => {signed => 1, branch => 'release'}],
         'Git::Push',
-        'GitHub::Update',
+        ['GitHub::Update' => {metacpan => 1}],
+
         'UploadToCPAN',
     ];
 }
@@ -74,6 +74,9 @@ has build_plugin => (
         if ($_[0]->payload->{custom_builder}) {
             return [ModuleBuild => {mb_class => 'My::Builder'}];
         } else {
+
+            # TODO add an option to handle experimental statis installs
+            # https://metacpan.org/pod/Dist::Zilla::Plugin::ModuleBuildTiny#static
             return 'ModuleBuildTiny';
         }
     });
@@ -104,8 +107,8 @@ sub configure {
         'AutoPrereqs',
         ['ChangelogFromGit::CPAN::Changes' => $change_opts],
         'ContributorsFile',
-        ['Git::Contributors' => {order_by => 'commits'}],
-        ['CopyFilesFromBuild' => {copy => [qw/README.md LICENSE/]}],
+        ['Git::Contributors'  => {order_by => 'commits'}],
+        ['CopyFilesFromBuild' => {copy     => [qw/README.md LICENSE/]}],
         'ExecDir',
         [
             'Git::Check' => {
@@ -120,28 +123,25 @@ sub configure {
                 exclude_match    => '(Changes|README.md|LICENSE)$',
             }
         ],
-        ['GitHub::Meta' => {metacpan => 1 }],
+        ['GitHub::Meta' => {homepage => 0}],
         'License',
         'Manifest',
-        'Meta::Contributors',
         ['MetaData::BuiltWith' => {show_config => 1}],
         'MetaJSON',
-        ['PodWeaver' => {config_plugin => '@Author::IOANR'}],
-        ['PkgVersion' => {use_package => 1}],
+        ['PodWeaver'  => {config_plugin => '@Author::IOANR'}],
+        ['PkgVersion' => {use_package   => 1}],
+        'Prereqs::AuthorDeps',
         'PruneCruft',
-        [ 'ReadmeAnyFromPod' => { type => 'gfm', location => 'build' } ],
+        ['ReadmeAnyFromPod' => {type => 'gfm', location => 'build'}],
         'ShareDir',
         'Signature',
         'MojibakeTests',
+        'AuthorSignatureTest',
         'Test::CheckDeps',
         'Test::Compile',
-        'Test::CPAN::Meta::JSON',
-        'Test::DistManifest',
         'Test::EOL',
-        ['Test::Kwalitee' => { skiptest => [qw/has_readme/]}],
-        'Test::MinimumVersion', # TODO only checks META.yml, which we don't have
+        ['Test::Kwalitee' => {skiptest => [qw/has_readme/]}],
         'Test::NoTabs',
-        'Test::Pod::LinkCheck',
         'Test::Pod::No404s',
         'Test::Portability',
         'Test::ReportPrereqs',
@@ -155,11 +155,10 @@ sub configure {
     # PodCoverageTests
     # PodSyntaxTests
 
-    push @plugins, @{$self->release_plugins};
-
+    push @plugins, $self->release_plugins->@*;
     my @add;
     while (my $p = shift @plugins) {
-        next if any { $_ eq $p } @{$arg->{disable}};
+        next if any { $_ eq $p } $arg->{disable}->@*;
         push @add, $p;
     }
 
@@ -186,7 +185,8 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Ioan Rogers
+=for :stopwords Ioan Rogers cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee
+diff irc mailto metadata placeholders metacpan
 
 =head1 NAME
 
@@ -194,7 +194,7 @@ Dist::Zilla::PluginBundle::Author::IOANR - Build dists the way IOANR likes
 
 =head1 VERSION
 
-version 1.172580
+version 1.173480
 
 =head1 OPTIONS
 
@@ -228,23 +228,43 @@ L<Module::Build::Tiny> with a custom build class set to C<My::Builder>
 If C<semantic_version> is true (the default), git tags will be in the form
 C<^v(\d+\.\d+\.\d+)$>. Otherwise they will be C<^v(\d+\.\d+)$>.
 
-=head1 BUGS AND LIMITATIONS
+=head1 SUPPORT
 
-You can make new bug reports, and view existing ones, through the
-web interface at L<https://github.com/ioanrogers/Dist-Zilla-PluginBundle-Author-IOANR/issues>.
+=head2 Perldoc
 
-=head1 AVAILABILITY
+You can find documentation for this module with the perldoc command.
 
-The project homepage is L<http://search.cpan.org/dist/Dist-Zilla-PluginBundle-Author-IOANR/>.
+  perldoc Dist::Zilla::PluginBundle::Author::IOANR
 
-The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
-site near you, or see L<https://metacpan.org/module/Dist::Zilla::PluginBundle::Author::IOANR/>.
+=head2 Websites
 
-=head1 SOURCE
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
 
-The development version is on github at L<http://github.com/ioanrogers/Dist-Zilla-PluginBundle-Author-IOANR>
-and may be cloned from L<git://github.com/ioanrogers/Dist-Zilla-PluginBundle-Author-IOANR.git>
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<https://metacpan.org/release/Dist-Zilla-PluginBundle-Author-IOANR>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests through the web interface at L<https://github.com/ioanrogers/Dist-Zilla-PluginBundle-Author-IOANR/issues>.
+You will be automatically notified of any progress on the request by the system.
+
+=head2 Source Code
+
+The source code is available for from the following locations:
+
+L<https://github.com/ioanrogers/Dist-Zilla-PluginBundle-Author-IOANR>
+
+  git clone git://github.com/ioanrogers/Dist-Zilla-PluginBundle-Author-IOANR.git
 
 =head1 AUTHOR
 
@@ -258,27 +278,4 @@ This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
-=head1 DISCLAIMER OF WARRANTY
-
-BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
-FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT
-WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER
-PARTIES PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND,
-EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE
-IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE
-SOFTWARE IS WITH YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME
-THE COST OF ALL NECESSARY SERVICING, REPAIR, OR CORRECTION.
-
-IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
-WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
-REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE LIABLE
-TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL, OR
-CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE
-SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
-RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
-FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
-SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH
-DAMAGES.
-
 =cut
